==> simplevis_1.1.1.tar.gz: simplevis/README.md <==
<img src="man/figures/logo.png" height="150" align = "right">

# simplevis

### Introduction

`simplevis` is a package of `ggplot2` and `leaflet` wrapper functions designed to simplify the creation of high quality graph and map visualisations. 

These functions only require inputs of data, variables and titles to provide beautiful interactive or image visualisations. However they allow for more flexibility if required. 

The intent is that high quality well-designed graphs and maps can be made more consistently with less effort, code and expertise than would otherwise be required.

### Installation

Install stable version from CRAN:
`install.packages("simplevis")`

Install development version from github:
`devtools::install_github("StatisticsNZ/simplevis")`

### Documentation

Webpage URL:

https://statisticsnz.github.io/simplevis/

R vignette:

`vignette("simplevis", "simplevis")`

---
__Copyright and Licensing__

The package is Crown copyright (c) 2020, Statistics New Zealand on behalf of the New Zealand Government, and is licensed under the MIT License.

<br /><a rel="license" href="http://creativecommons.org/licenses/by/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by/4.0/88x31.png" /></a><br />This document is Crown copyright (c) 2020, Statistics New Zealand on behalf of the New Zealand Government, and is licensed under the Creative Commons Attribution 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by/4.0/ or send a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.

==> simplevis_1.1.4.tar.gz: simplevis/README.md <==
<img src="man/figures/logo.png" height="150" align = "right">

# simplevis

### Introduction

`simplevis` is a package of `ggplot2` and `leaflet` wrapper functions designed to simplify the creation of high quality graph and map visualisations. 

These functions only require inputs of data, variables and titles to provide beautiful interactive or image visualisations. However they allow for more flexibility if required. 

The intent is that high quality well-designed graphs and maps can be made more consistently with less effort, code and expertise than would otherwise be required.

### Installation

Install stable version from CRAN:
`install.packages("simplevis")`

Install development version from github:
`devtools::install_github("statisticsNZ/simplevis")`

### Documentation

Webpage URL:

https://statisticsnz.github.io/simplevis/

R vignette:

`vignette("simplevis", "simplevis")`

---
__Copyright and Licensing__

The package is Crown copyright (c) 2020, Statistics New Zealand on behalf of the New Zealand Government, and is licensed under the MIT License.

<br /><a rel="license" href="http://creativecommons.org/licenses/by/4.0/"><img alt="Creative Commons License" style="border-width:0" src="https://i.creativecommons.org/l/by/4.0/88x31.png" /></a><br />This document is Crown copyright (c) 2020, Statistics New Zealand on behalf of the New Zealand Government, and is licensed under the Creative Commons Attribution 4.0 International License. To view a copy of this license, visit http://creativecommons.org/licenses/by/4.0/ or send a letter to Creative Commons, PO Box 1866, Mountain View, CA 94042, USA.
